<?php
/**
 * @file
 * Contains \Drupal\spectra_expire\Entity\SpectraExpirationPolicy.
 */

namespace Drupal\spectra_expire\Entity;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\user\UserInterface;
use Drupal\spectra_expire\Controller\SpectraExpireController;
use Drupal\Core\Entity\EntityChangedTrait;

/**
 * Defines the SpectraExpirationPolicy entity.
 *
 * @ingroup spectra_expire
 *
 *
 * @ContentEntityType(
 * id = "spectra_expire_policy",
 * label = @Translation("Spectra Expiration Policy"),
 * handlers = {
 *   "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *   "list_builder" = "Drupal\spectra_expire\Entity\Controller\SpectraExpirationPolicyListBuilder",
 *   "views_data" = "Drupal\spectra_expire\Entity\Views\SpectraExpirationPolicyViewsData",
 *   "form" = {
 *     "add" = "Drupal\spectra_expire\Form\SpectraExpirationPolicyForm",
 *     "edit" = "Drupal\spectra_expire\Form\SpectraExpirationPolicyForm",
 *     "delete" = "Drupal\spectra_expire\Form\SpectraExpirationPolicyDeleteForm",
 *   },
 *   "access" = "Drupal\spectra_expire\SpectraExpirationPolicyAccessControlHandler",
 * },
 * base_table = "spectra_expire_policy",
 * admin_permission = "administer spectra_expire",
 * fieldable = FALSE,
 * entity_keys = {
 *   "id" = "policy_id",
 *   "uuid" = "uuid",
 * },
 * links = {
 *   "canonical" = "/spectra_expire_policy/{spectra_expire_policy}",
 *   "edit-form" = "/spectra_expire_policy/{spectra_expire_policy}/edit",
 *   "delete-form" = "/spectra_expire_policy/{spectra_expire_policy}/delete",
 *   "collection" = "/spectra_expire_policy/list"
 * },
 * )
 */
class SpectraExpirationPolicy extends ContentEntityBase {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   *
   * Define the field properties here.
   *
   * Field name, type and size determine the table structure.
   *
   * In addition, we can define how the field and its content can be manipulated
   * in the GUI. The behaviour of the widgets used can be determined here.
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {

    // Standard field, used as unique if primary index.
    $fields['policy_id'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('ID'))
      ->setDescription(t('The ID of the SpectraExpirationPolicy entity.'))
      ->setReadOnly(TRUE);

    // Standard field, unique outside of the scope of the current project.
    $fields['uuid'] = BaseFieldDefinition::create('uuid')
      ->setLabel(t('UUID'))
      ->setDescription(t('The UUID of the SpectraExpirationPolicy entity.'))
      ->setReadOnly(TRUE);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['active'] = BaseFieldDefinition::create('list_integer')
      ->setLabel(t('Active'))
      ->setDescription(t('Active items are evaluated during each cron run.'))
      ->setSettings(array(
        'allowed_values' => array(
          '0' => 'Inactive',
          '1' => 'Active',
        ),
      ))
      ->setDefaultValue('1')
      ->setDisplayOptions('view', array(
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ))
      ->setDisplayOptions('form', array(
        'type' => 'string_textfield',
        'weight' => -4,
      ))
      ->setRequired(TRUE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['select_method'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Statement Selection Method'))
      ->setDescription(t('How will we select statement entities?.'))
      ->setSettings(array(
        'default_value' => 'default',
        'max_length' => 255,
        'text_processing' => 0,
      ));

    $fields['entity_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Statement/Data Type'))
      ->setDescription(t('The statement_type or data_type of affected statement entities. Leave blank for all types'))
      ->setSettings(array(
        'default_value' => 'default',
        'max_length' => 255,
        'text_processing' => 0,
      ));

    $fields['expire_age'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Age for expired items'))
      ->setDescription(t('The age of items to expire, in seconds. Remember that 1 day  = 86400 seconds, and 30 days = 2592000 seconds .'))
      ->setSettings(array(
        'default_value' => 'default',
        'max_length' => 255,
        'text_processing' => 0,
      ));

    $fields['expire_method'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Method for expiring items.'))
      ->setDescription(t('The method to use when expiring items.'))
      ->setSettings(array(
        'default_value' => 'default',
        'max_length' => 255,
        'text_processing' => 0,
      ));

    $fields['expire_max'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Maximum number of items to expire per cron run.'))
      ->setDescription(t('The maximum number of items to expire in a cron run. Note that oldest items (in order of database ID) are expired first.'))
      ->setSettings(array(
        'default_value' => 'default',
        'max_length' => 255,
        'text_processing' => 0,
      ));

    return $fields;
  }

}